package com.ruoyi.base.mapper;

import java.util.List;
import com.ruoyi.base.domain.RobotOpsBroadcastTask;

/**
 * 播报任务Mapper接口
 * 
 * @author ruoyi
 * @date 2026-04-27
 */
public interface RobotOpsBroadcastTaskMapper 
{
    /**
     * 查询播报任务
     * 
     * @param id 播报任务主键
     * @return 播报任务
     */
    public RobotOpsBroadcastTask selectRobotOpsBroadcastTaskById(Long id);

    /**
     * 查询播报任务列表
     * 
     * @param robotOpsBroadcastTask 播报任务
     * @return 播报任务集合
     */
    public List<RobotOpsBroadcastTask> selectRobotOpsBroadcastTaskList(RobotOpsBroadcastTask robotOpsBroadcastTask);

    /**
     * 新增播报任务
     * 
     * @param robotOpsBroadcastTask 播报任务
     * @return 结果
     */
    public int insertRobotOpsBroadcastTask(RobotOpsBroadcastTask robotOpsBroadcastTask);

    /**
     * 修改播报任务
     * 
     * @param robotOpsBroadcastTask 播报任务
     * @return 结果
     */
    public int updateRobotOpsBroadcastTask(RobotOpsBroadcastTask robotOpsBroadcastTask);

    /**
     * 删除播报任务
     * 
     * @param id 播报任务主键
     * @return 结果
     */
    public int deleteRobotOpsBroadcastTaskById(Long id);

    /**
     * 批量删除播报任务
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRobotOpsBroadcastTaskByIds(Long[] ids);
}
