package com.ruoyi.web.controller.base;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.base.domain.RobotOpsBroadcastTask;
import com.ruoyi.base.service.IRobotOpsBroadcastTaskService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 播报任务Controller
 *
 * @author ruoyi
 * @date 2026-04-27
 */
@RestController
@RequestMapping("/base/broadcastTask")
public class RobotOpsBroadcastTaskController extends BaseController
{
    @Autowired
    private IRobotOpsBroadcastTaskService robotOpsBroadcastTaskService;

    /**
     * 查询播报任务列表
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:list')")
    @GetMapping("/list")
    public TableDataInfo list(RobotOpsBroadcastTask robotOpsBroadcastTask)
    {
        startPage();
        List<RobotOpsBroadcastTask> list = robotOpsBroadcastTaskService.selectRobotOpsBroadcastTaskList(robotOpsBroadcastTask);
        return getDataTable(list);
    }

    /**
     * 导出播报任务列表
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:export')")
    @Log(title = "播报任务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RobotOpsBroadcastTask robotOpsBroadcastTask)
    {
        List<RobotOpsBroadcastTask> list = robotOpsBroadcastTaskService.selectRobotOpsBroadcastTaskList(robotOpsBroadcastTask);
        ExcelUtil<RobotOpsBroadcastTask> util = new ExcelUtil<RobotOpsBroadcastTask>(RobotOpsBroadcastTask.class);
        util.exportExcel(response, list, "播报任务数据");
    }

    /**
     * 获取播报任务详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(robotOpsBroadcastTaskService.selectRobotOpsBroadcastTaskById(id));
    }

    /**
     * 新增播报任务
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:add')")
    @Log(title = "播报任务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RobotOpsBroadcastTask robotOpsBroadcastTask)
    {
        return toAjax(robotOpsBroadcastTaskService.insertRobotOpsBroadcastTask(robotOpsBroadcastTask));
    }

    /**
     * 修改播报任务
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:edit')")
    @Log(title = "播报任务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RobotOpsBroadcastTask robotOpsBroadcastTask)
    {
        return toAjax(robotOpsBroadcastTaskService.updateRobotOpsBroadcastTask(robotOpsBroadcastTask));
    }

    /**
     * 删除播报任务
     */
    @PreAuthorize("@ss.hasPermi('base:broadcastTask:remove')")
    @Log(title = "播报任务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(robotOpsBroadcastTaskService.deleteRobotOpsBroadcastTaskByIds(ids));
    }
}
